@@ -73,7 +73,7 @@ public:
 
     void addAction(QAction* action, Qt::ToolButtonStyle style = Qt::ToolButtonIconOnly)
     {
-        QToolButton* button = new QToolButton;
+        auto* button = new QToolButton;
         button->setDefaultAction(action);
         button->setToolButtonStyle(style);
         button->setAutoRaise(true);
@@ -119,7 +119,7 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
     // mAutoHideContainer
     mAutoHideContainer = new FullScreenBar(autoHideParentWidget);
     mAutoHideContainer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-    QVBoxLayout* layout = new QVBoxLayout(mAutoHideContainer);
+    auto* layout = new QVBoxLayout(mAutoHideContainer);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->setSpacing(0);
 
@@ -167,7 +167,7 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
     mInformationContainer->setAutoFillBackground(true);
     mInformationContainer->setBackgroundRole(QPalette::Mid);
     mInformationContainerShadow = new ShadowFilter(mInformationContainer);
-    QHBoxLayout* hLayout = new QHBoxLayout(mInformationContainer);
+    auto* hLayout = new QHBoxLayout(mInformationContainer);
     hLayout->setContentsMargins(0, 0, 0, 0);
     hLayout->addWidget(mInformationLabel);
     hLayout->addWidget(mDocumentCountLabel);
@@ -175,7 +175,7 @@ void FullScreenContent::init(KActionCollection* actionCollection, QWidget* autoH
     // Thumbnail bar
     mThumbnailBar = new ThumbnailBarView(mContent);
     mThumbnailBar->setThumbnailScaleMode(ThumbnailView::ScaleToSquare);
-    ThumbnailBarItemDelegate* delegate = new ThumbnailBarItemDelegate(mThumbnailBar);
+    auto* delegate = new ThumbnailBarItemDelegate(mThumbnailBar);
     mThumbnailBar->setItemDelegate(delegate);
     mThumbnailBar->setSelectionMode(QAbstractItemView::ExtendedSelection);
     // Calculate minimum bar height to give mInformationLabel exactly two lines height
@@ -305,7 +305,7 @@ void FullScreenContent::updateLayout()
     if (GwenviewConfig::showFullScreenThumbnails()) {
         mRightToolBar->setDirection(QBoxLayout::TopToBottom);
 
-        QHBoxLayout* layout = new QHBoxLayout(mContent);
+        auto* layout = new QHBoxLayout(mContent);
         layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(0);
         QVBoxLayout* vLayout;
@@ -349,7 +349,7 @@ void FullScreenContent::updateLayout()
     } else {
         mRightToolBar->setDirection(QBoxLayout::RightToLeft);
 
-        QHBoxLayout* layout = new QHBoxLayout(mContent);
+        auto* layout = new QHBoxLayout(mContent);
         layout->setContentsMargins(0, 0, 0, 0);
         layout->setSpacing(0);
         layout->addWidget(mToolBar);
@@ -437,7 +437,7 @@ void FullScreenContent::showOptionsMenu()
 
     // Put widget in a menu
     QMenu menu;
-    QWidgetAction* action = new QWidgetAction(&menu);
+    auto* action = new QWidgetAction(&menu);
     action->setDefaultWidget(widget);
     menu.addAction(action);
 
