@@ -32,9 +32,13 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Cambridge, MA 02110-1301, USA
 namespace Gwenview
 {
 
+class AlphaBackgroundItem;
+
 struct AbstractImageViewPrivate;
 /**
- *
+ * The abstract base class used to implement common functionality of raster and vector image views
+ * like for example zooming, computing the area where the image will be displayed in the view and
+ * dealing with a background for transparent areas.
  */
 class AbstractImageView : public QGraphicsWidget
 {
@@ -119,12 +123,17 @@ public:
 
     void resetDragCursor();
 
+    AlphaBackgroundItem* backgroundItem() const;
+
 public Q_SLOTS:
     void updateCursor();
 
 Q_SIGNALS:
+    /** Emitted when the zoom mode changes to or from "Fit". */
     void zoomToFitChanged(bool);
+    /** Emitted when the zoom mode changes to or from "Fill". */
     void zoomToFillChanged(bool);
+    /** Emitted when the zoom value changes in any way. */
     void zoomChanged(qreal);
     void zoomInRequested(const QPointF&);
     void zoomOutRequested(const QPointF&);
@@ -135,10 +144,6 @@ Q_SIGNALS:
     void toggleFullScreenRequested();
 
 protected:
-    virtual void setAlphaBackgroundMode(AlphaBackgroundMode mode) = 0;
-    virtual void setAlphaBackgroundColor(const QColor& color) = 0;
-    const QPixmap& alphaBackgroundTexture() const;
-
     virtual void loadFromDocument() = 0;
     virtual void onZoomChanged() = 0;
     /**
@@ -152,6 +157,8 @@ protected:
      */
     virtual void onScrollPosChanged(const QPointF& oldPos) = 0;
 
+    void onImageRectUpdated();
+
     void resizeEvent(QGraphicsSceneResizeEvent* event) override;
     void focusInEvent(QFocusEvent* event) override;
 
