@@ -45,7 +45,7 @@ void ContextManagerTest::testRemove()
     // there is any, otherwise to the previous image.
 
     SandBoxDir sandBox;
-    sandBox.fill(QStringList() << "a" << "b" << "c");
+    sandBox.fill(QStringList() << QStringLiteral("a") << QStringLiteral("b") << QStringLiteral("c"));
     QUrl dirUrl = QUrl::fromLocalFile(sandBox.absolutePath());
 
     SortedDirModel dirModel;
@@ -93,7 +93,7 @@ void ContextManagerTest::testInvalidDirUrl()
         DirLister()
         : mOpenUrlCalled(false)
         {
-            setAutoErrorHandlingEnabled(false, nullptr);
+            setAutoErrorHandlingEnabled(false);
         }
 
         bool openUrl(const QUrl &url, OpenUrlFlags flags = NoFlags) override
@@ -106,7 +106,7 @@ void ContextManagerTest::testInvalidDirUrl()
     };
 
     SortedDirModel dirModel;
-    DirLister* dirLister = new DirLister;
+    auto* dirLister = new DirLister;
     dirModel.setDirLister(dirLister);
     ContextManager manager(&dirModel, nullptr);
 
